{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Fuzzy inference system\n",
    "The goal of this notebook is to provide an implementation allowing you to explore the creation of a fuzzy inference system. We will demonstrate the use of this implementation in the tourist prediction problem, and we will ask you to test it in other problems."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "import numpy as np\n",
    "import matplotlib.pyplot as pl\n",
    "from mpl_toolkits.mplot3d import Axes3D\n",
    "from matplotlib import cm\n",
    "\n",
    "%matplotlib inline"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The implementation of the linguistic variable and the fuzzy rule are not written here. Instead they are loaded from python files."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "import linguistic_variable as lv\n",
    "import fuzzy_rule as fr"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The constructor of the implementation of fuzzy inference system we propose receives 3 arguments as inputs:\n",
    "- rules: a list of rules of type FuzzyRules (in file fuzzy_rule.py)\n",
    "- aggregator: the function to use as aggregator. Options are:\n",
    "    - OR_max: maximum\n",
    "    - OR_probsum: probabilistic sum\n",
    "    - OR_boundsum: bounded sum\n",
    "- defuzzifier: the method used for defuzzifying the output. Options are:\n",
    "    - COA: center of areas\n",
    "    - MOM: minimum of maximums"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "class FIS:\n",
    "    \"\"\"\n",
    "    This class implements a Fuzzy Inference System (FIS).\n",
    "    Available aggregators are:\n",
    "    - OR_max: maximum\n",
    "    - OR_probsum: probabilistic sum\n",
    "    - OR_boundsum: bounded sum\n",
    "    Available defuzzifiers are:\n",
    "    - COA: center of areas\n",
    "    - MOM: minimum of maximums\n",
    "    \"\"\"\n",
    "    \n",
    "    def __mom(v, m):\n",
    "        i = np.argmax(m)\n",
    "        y_inf = v[min(i)]\n",
    "        y_sup = v[max(i)]\n",
    "        return (y_inf + y_sup) / 2.0\n",
    "        \n",
    "    __fuzzy_aggregators = {'OR_max': np.maximum,\n",
    "                           'OR_probsum': lambda x,y: np.add(x, y) - np.multiply(x, y),\n",
    "                           'OR_boundsum': lambda x,y: np.minimum(1, np.add(x, y))}\n",
    "    __fuzzy_defuzzifiers = {'COA': lambda v,m: np.sum(np.multiply(v,m)) / np.sum(m),\n",
    "                            'MOM': __mom}\n",
    "    \n",
    "    def __init__(self, rules, aggregator='OR_max', defuzzifier='COA'):\n",
    "        \"\"\"\n",
    "        Three parameters are needed:\n",
    "        rules: a list of objects of type FuzzyRule containing the rules of the system\n",
    "        aggregator: the fuzzy operator to be used to aggregate the rules outputs\n",
    "        defuzzifier: the defuzzifier function to use\n",
    "        \"\"\"\n",
    "        self.rules = rules\n",
    "        self.input_variables = set()\n",
    "        for r in self.rules:\n",
    "            for a in r.antecedent:\n",
    "                self.input_variables.add(a[0])\n",
    "            self.output_variable = r.consequent[0]\n",
    "        \n",
    "        assert aggregator in self.__fuzzy_aggregators.keys()\n",
    "        self.aggregator = self.__fuzzy_aggregators[aggregator]\n",
    "        \n",
    "        assert defuzzifier in self.__fuzzy_defuzzifiers.keys()\n",
    "        self.defuzzifier = defuzzifier\n",
    "        \n",
    "        self.input_values = dict()\n",
    "        self.fuzzified_output = np.zeros(len(self.output_variable.input_values))\n",
    "        self.defuzzified_output = 0.0\n",
    "    \n",
    "    def __str__(self):\n",
    "        to_return = 'Input variables:\\n'\n",
    "        to_return += '\\t' + str([i_v.name for i_v in self.input_variables]) + '\\n'\n",
    "        to_return += 'Output variables:\\n'\n",
    "        to_return += '\\t' + self.output_variable.name + '\\n'\n",
    "        to_return += 'Rules:\\n'\n",
    "        for r in self.rules:\n",
    "            to_return += '\\t' + str(r) + '\\n'\n",
    "        return to_return\n",
    "    \n",
    "    def compute_antecedent_activations(self, input_values):\n",
    "        \"\"\"\n",
    "        This function computes the activation of the antecedent of all rules.\n",
    "        \"\"\"\n",
    "        self.input_values = input_values\n",
    "        for r in self.rules:\n",
    "            r.compute_antecedent_activation(input_values)\n",
    "    \n",
    "    def compute_consequent_activations(self):\n",
    "        \"\"\"\n",
    "        This function computes the activation of the consequent of all rules.\n",
    "        \"\"\"\n",
    "        for r in self.rules:\n",
    "            r.compute_consequent_activation()\n",
    "    \n",
    "    def aggregate(self):\n",
    "        \"\"\"\n",
    "        This function performs the aggregation of the rules outputs\n",
    "        \"\"\"\n",
    "        self.fuzzified_output = np.zeros(len(self.output_variable.input_values))\n",
    "        for r in self.rules:\n",
    "            self.fuzzified_output = self.aggregator(self.fuzzified_output, r.consequent_activation)\n",
    "    \n",
    "    def defuzzify(self):\n",
    "        \"\"\"\n",
    "        This function defuzzifies the fuzzified_output of the system\n",
    "        \"\"\"\n",
    "        self.defuzzified_output = self.__fuzzy_defuzzifiers[self.defuzzifier](self.output_variable.input_values, self.fuzzified_output)\n",
    "        return self.defuzzified_output\n",
    "    \n",
    "    def plot_variables(self):\n",
    "        i = 1\n",
    "        n_lv = len(self.input_variables) + 1\n",
    "        for i_v in self.input_variables:\n",
    "            pl.subplot(1, n_lv, i)\n",
    "            i += 1\n",
    "            i_v.plot()\n",
    "        pl.subplot(1, n_lv, i)\n",
    "        self.output_variable.plot()\n",
    "    \n",
    "    def plot_rules(self):\n",
    "        n_r = len(self.rules)\n",
    "        for i, r in enumerate(self.rules):\n",
    "            pl.subplot(1, n_r, i+1)\n",
    "            r.plot()\n",
    "    \n",
    "    def plot_output(self):\n",
    "        pl.plot(self.output_variable.input_values, self.fuzzified_output)\n",
    "        pl.axvline(self.defuzzified_output, color='black', linestyle='--')\n",
    "        pl.ylim(0, 1.05)\n",
    "        pl.grid()\n",
    "        pl.title(self.output_variable.name + str(self.input_values))\n",
    "    \n",
    "    def plot2D(self, ax=None):\n",
    "        \"\"\"\n",
    "        Only works for systems with two inputs!!\n",
    "        \"\"\"\n",
    "        \n",
    "        assert len(self.input_variables) == 2\n",
    "        \n",
    "        vars_list = []\n",
    "        for v in self.input_variables:\n",
    "            vars_list.append(v)\n",
    "            \n",
    "        var1 = vars_list[0]\n",
    "        var2 = vars_list[1]\n",
    "        n_var1 = len(var1.input_values)\n",
    "        n_var2 = len(var2.input_values)\n",
    "        \n",
    "        input_values = {var1.name:0, var2.name:0}\n",
    "        X, Y = np.meshgrid(var1.input_values, var2.input_values)\n",
    "        Z = np.zeros((n_var2, n_var1))\n",
    "        \n",
    "        for i in np.arange(n_var1):\n",
    "            for j in np.arange(n_var2):\n",
    "                input_values[var1.name] = X[j,i]\n",
    "                input_values[var2.name] = Y[j,i]\n",
    "                self.compute_antecedent_activations(input_values)\n",
    "                self.compute_consequent_activations()\n",
    "                self.aggregate()\n",
    "                Z[j,i] = self.defuzzify()\n",
    "\n",
    "        if ax is None:\n",
    "            ax = pl.gca(projection='3d')\n",
    "        surf = ax.plot_surface(X, Y, Z, rstride=1, cstride=1, cmap=cm.coolwarm, linewidth=0, antialiased=False)\n",
    "        ax.set_xlabel(var1.name)\n",
    "        ax.set_ylabel(var2.name)\n",
    "        ax.set_zlabel(self.output_variable.name)\n",
    "        \n",
    "    def plot(self, size=None):\n",
    "        if size is None:\n",
    "            size = (12,4)\n",
    "        pl.figure(figsize=size)\n",
    "        self.plot_variables()\n",
    "        pl.figure(figsize=size)\n",
    "        self.plot_rules()\n",
    "        pl.figure(figsize=size)\n",
    "        self.plot_output()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## An example: \"the tourists prediction problem\""
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "We start by creating the linguistic variables involved in the problem"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "temperature = lv.LinguisticVariable('temperature', 0, 35, [17, 20, 26, 29], ['cold', 'warm', 'hot'], res=1.0)\n",
    "sunshine = lv.LinguisticVariable('sunshine', 0, 100, [30, 50, 50, 100], ['cloudy', 'partsunny', 'sunny'], res=1.0)\n",
    "tourists = lv.LinguisticVariable('tourists', 0, 100, [0, 50, 50, 100], ['low', 'medium', 'high'], res=1.0)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAA3AAAAEKCAYAAABTzLdZAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\ngZ43BGBBqYgAAAAASUVORK5CYII=\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7fde9fcc1810>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "pl.figure(figsize=(15,4))\n",
    "pl.subplot(1,3,1)\n",
    "temperature.plot()\n",
    "pl.subplot(1,3,2)\n",
    "sunshine.plot()\n",
    "pl.subplot(1,3,3)\n",
    "tourists.plot()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Then, we create the three rules describing the system"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "rule_1 = fr.FuzzyRule('OR_max', [(temperature, 'hot'), (sunshine, 'sunny')], (tourists, 'high'), 'MIN')\n",
    "rule_2 = fr.FuzzyRule('AND_min', [(temperature, 'warm'), (sunshine, 'partsunny')], (tourists, 'medium'), 'MIN')\n",
    "rule_3 = fr.FuzzyRule('OR_max', [(temperature, 'cold'), (sunshine, 'cloudy')], (tourists, 'low'), 'MIN')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Fuzzy rule:\n",
      "\tIF temperature IS hot OR sunshine IS sunny\n",
      "\tTHEN tourists is high\n",
      "\tAntecedent activation: 0.0\n",
      "Fuzzy rule:\n",
      "\tIF temperature IS warm AND sunshine IS partsunny\n",
      "\tTHEN tourists is medium\n",
      "\tAntecedent activation: 0.0\n",
      "Fuzzy rule:\n",
      "\tIF temperature IS cold OR sunshine IS cloudy\n",
      "\tTHEN tourists is low\n",
      "\tAntecedent activation: 0.0\n"
     ]
    }
   ],
   "source": [
    "print rule_1\n",
    "print rule_2\n",
    "print rule_3"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Finally, we create the Fuzzy Inference System"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "tourist_prediction_example = FIS([rule_1, rule_2, rule_3])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {
    "collapsed": false,
    "scrolled": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Input variables:\n",
      "\t['temperature', 'sunshine']\n",
      "Output variables:\n",
      "\ttourists\n",
      "Rules:\n",
      "\tFuzzy rule:\n",
      "\tIF temperature IS hot OR sunshine IS sunny\n",
      "\tTHEN tourists is high\n",
      "\tAntecedent activation: 0.0\n",
      "\tFuzzy rule:\n",
      "\tIF temperature IS warm AND sunshine IS partsunny\n",
      "\tTHEN tourists is medium\n",
      "\tAntecedent activation: 0.0\n",
      "\tFuzzy rule:\n",
      "\tIF temperature IS cold OR sunshine IS cloudy\n",
      "\tTHEN tourists is low\n",
      "\tAntecedent activation: 0.0\n",
      "\n"
     ]
    }
   ],
   "source": [
    "print tourist_prediction_example"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAcwAAAHMCAYAAABY25iGAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nRU5ErkJggg==\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7fde9fd69810>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "pl.figure(figsize=(8,8))\n",
    "tourist_prediction_example.plot2D()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "And we define some input values for testing"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "input_values = {'temperature': 19, 'sunshine': 60}"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Antecedent activation"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "tourist_prediction_example.compute_antecedent_activations(input_values)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "print tourist_prediction_example"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "pl.figure(figsize=(12,4))\n",
    "tourist_prediction_example.plot_variables()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Consequent activation"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "tourist_prediction_example.compute_consequent_activations()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "pl.figure(figsize=(12,4))\n",
    "tourist_prediction_example.plot_rules()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Aggregation and Defuzzification"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "tourist_prediction_example.aggregate()\n",
    "tourist_prediction_example.defuzzify()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "tourist_prediction_example.plot_output()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Plot"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "tourist_prediction_example.plot()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "collapsed": true
   },
   "source": [
    "## Exercise\n",
    "1. Reproduce the fuzzy systems studied in class, simulate their behaviour, compare your results with those discussed in class, and comment:\n",
    "    - Car acceleration problem. How would you create the system given that the current implementation does not have a default rule (it does not support the \"else\" condition)?\n",
    "    - Inverted pendulum problem. What could you say about the use of the default rule in this case?\n",
    "    - Temperature control  \n",
    "\n",
    "2. The current implementation of FIS does not have a default rule. Modify the provided implementation and add a default rule to the fuzzy inference system. Show its behaviour using the \"car acceleration problem\"\n",
    "\n",
    "3. The current implementation of FIS is of type Mamdani. Modify the sources and create a FIS of type singleton. Show its behaviour using the \"temperature control problem\". You should:\n",
    "    - create a new linguistic variable that does not interpolate between known values\n",
    "    - create a new rule which employs the new type of linguistic value in its consequent"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 2",
   "language": "python",
   "name": "python2"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 2
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython2",
   "version": "2.7.9"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 0
}
